==> apache-cxf-3.6.7-src.zip: apache-cxf-3.6.7-src/rt/rs/microprofile-client/src/test/java/org/apache/cxf/microprofile/client/mock/HeaderCaptureClientRequestFilter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.microprofile.client.mock;

import java.io.IOException;

import javax.ws.rs.client.ClientRequestContext;
import javax.ws.rs.client.ClientRequestFilter;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.core.Response;

public class HeaderCaptureClientRequestFilter implements ClientRequestFilter {

    private static MultivaluedMap<String, String> outboundHeaders;

    public static MultivaluedMap<String, String> getOutboundHeaders() {
        return outboundHeaders;
    }

    public static void setOutboundHeaders(MultivaluedMap<String, String> newHeaders) {
        outboundHeaders = newHeaders;
    }

    @Override
    public void filter(ClientRequestContext ctx) throws IOException {
        setOutboundHeaders(ctx.getStringHeaders());
        ctx.abortWith(Response.ok("SUCCESS").build());
    }

}

==> apache-cxf-4.0.8-src.zip: apache-cxf-4.0.8-src/rt/rs/microprofile-client/src/test/java/org/apache/cxf/microprofile/client/mock/HeaderCaptureClientRequestFilter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.microprofile.client.mock;

import java.io.IOException;

import jakarta.ws.rs.client.ClientRequestContext;
import jakarta.ws.rs.client.ClientRequestFilter;
import jakarta.ws.rs.core.MultivaluedMap;
import jakarta.ws.rs.core.Response;

public class HeaderCaptureClientRequestFilter implements ClientRequestFilter {

    private static MultivaluedMap<String, String> outboundHeaders;

    public static MultivaluedMap<String, String> getOutboundHeaders() {
        return outboundHeaders;
    }

    public static void setOutboundHeaders(MultivaluedMap<String, String> newHeaders) {
        outboundHeaders = newHeaders;
    }

    @Override
    public void filter(ClientRequestContext ctx) throws IOException {
        setOutboundHeaders(ctx.getStringHeaders());
        ctx.abortWith(Response.ok("SUCCESS").build());
    }

}
